@@ -22,6 +22,7 @@
 #'  matrix give the index of the top component ("V" in PCA and "S" in ICA) at
 #'  each timepoint.
 #'
+#' @importFrom fMRItools scale_med
 #' @export
 artifact_images <- function(psx, idx=NULL, use_dt=TRUE){
 
@@ -48,14 +49,14 @@ artifact_images <- function(psx, idx=NULL, use_dt=TRUE){
       stop("No directions. Run `pscrub` again with `get_dirs=TRUE`.") 
     }
     V <- psx$PCA$V
-  } else if ("fusedPCA" %in% names(psx)) {
-    U <- psx$fusedPCA$U
-    if (!("V" %in% names(psx$PCA))) { 
-      stop("No directions. Run `pscrub` again with `get_dirs=TRUE`.")
-    }
-    V <- psx$fusedPCA$V
+  # } else if ("fusedPCA" %in% names(psx)) {
+  #   U <- psx$fusedPCA$U
+  #   if (!("V" %in% names(psx$PCA))) { 
+  #     stop("No directions. Run `pscrub` again with `get_dirs=TRUE`.")
+  #   }
+  #   V <- psx$fusedPCA$V
   } else if ("ICA" %in% names(psx)) {
-    U <- scale_med(psx$ICA$M)
+    U <- fMRItools::scale_med(psx$ICA$M)
     if (!("S" %in% names (psx$ICA))) {
       stop("No directions. Run `pscrub` again with `get_dirs=TRUE`.")
     }
@@ -90,50 +91,4 @@ artifact_images <- function(psx, idx=NULL, use_dt=TRUE){
   colnames(lev_imgs$top) <- NULL
 
   lev_imgs
-}
-
-#' Undo a volumetric mask
-#' 
-#' Un-applies a mask to vectorized data to yield its volumetric representation.
-#'  The mask and data should have compatible dimensions: the number of rows in
-#'  \code{dat} should equal the number of locations within the \code{mask}.
-#' 
-#' @param dat Data matrix with locations along the rows and measurements along 
-#'  the columns. If only one set of measurements were made, this may be a 
-#'  vector.
-#' @param mask Volumetric binary mask. \code{TRUE} indicates voxels inside the
-#'  mask.
-#' @param fill The value for locations outside the mask. Default: \code{NA}.
-#'
-#' @return The 3D or 4D unflattened volume array
-#'
-#' @export
-#' 
-unmask_vol <- function(dat, mask, fill=NA) {
-
-  # Check that dat is a vector or matrix.
-  if (is.vector(dat) || is.factor(dat)) { dat <- matrix(dat, ncol=1) }
-  stopifnot(length(dim(dat)) == 2)
-
-  # Check that mask is numeric {0, 1} or logical, and is 3D.
-  if (is.numeric(mask)) {
-    mask_vals <- unique(as.vector(mask))
-    stopifnot(length(mask_vals) <= 2)
-    stopifnot(all(mask_vals %in% c(0,1)))
-    mask <- array(as.logical(mask), dim=dim(mask))
-  }
-  stopifnot(length(dim(mask)) == 3)
-
-  # Other checks.
-  stopifnot(is.vector(fill) && length(fill)==1)
-  stopifnot(sum(mask) == nrow(dat))
-
-  # Make volume and fill.
-  vol <- array(fill, dim=c(dim(mask), ncol(dat)))
-  for (ii in seq_len(ncol(dat))) {
-    vol[,,,ii][mask] <- dat[,ii]
-  }
-  if (ncol(dat)==1) { vol <- vol[,,,1] }
-
-  vol
 }
\ No newline at end of file
