@@ -1,7 +1,7 @@
 test_that("pscrub works", {
   psx <- testthat::expect_warning(fMRIscrub:::pscrub_multi(
     Dat1,
-    projection = "all"
+    projection = c("ICA", "ICA_kurt"), # "all"
   ))
   myplot <- fMRIscrub:::plot.scrub_projection_multi(psx)
 
